@@ -3,6 +3,9 @@
 //
 // Copyright: See COPYING file that comes with this distribution
 //
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 
 #include "debuglistener.h"
 #include "highlightevent.h"
